=====================
 Invenio-REST v1.0.0
=====================

Invenio-REST v1.0.0 was released on January 7, 2016.

About
-----

REST API module for Invenio.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-rest==1.0.0

Documentation
-------------

   http://pythonhosted.org/invenio-rest/

Happy hacking and thanks for flying Invenio-REST.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-rest
|   URL: http://invenio-software.org
